@@ -32,7 +32,7 @@
 package GD::Graph;
 
 ($GD::Graph::prog_version) = '$Revision: 1.55 $' =~ /\s([\d.]+)/;
-$GD::Graph::VERSION = '1.54';
+$GD::Graph::VERSION = '1.55';
 
 use strict;
 use GD;
@@ -347,7 +347,8 @@ sub _read_logo_file
             pack("H8",'ffd8ffe0') => "jpeg",
             'GIF8' => "gif",
             '.PNG' => "png",
-            '/* X'=> "xpm", # technically '/* XPM */', but I'm hashing, here
+            '/* X' => "xpm", # technically '/* XPM */', but I'm hashing, here
+            '#def' => "xbm",
         );
         if (my $match = $magic{ substr $logodata, 0, 4 }) {
             push @tried, $match;
@@ -607,6 +608,18 @@ Create a pie chart.
 
 =head1 DISTRIBUTION STATUS
 
+=head2 2023 Update
+
+This new release fixes some tests that started to fail based on
+some changes in dependencies. We help this gets all tests passing
+again so users can install cleanly again.
+
+The new active repo is here: L<https://github.com/bestpractical/gdgraph>.
+
+You can continue to use L<https://rt.cpan.org> for bug reports.
+
+=head2 Status from 2013
+
 Distribution has no releases since 2007. It has new maintainer starting
 of 1.45 and my plan is to keep modules backwards compatible as much as
 possible, fix bugs with test cases, apply patches and release new versions
@@ -1783,9 +1796,9 @@ for all concerned.
 =head1 AUTHOR
 
 Martien Verbruggen E<lt>mgjv@tradingpost.com.auE<gt>
-
-Current maintenance (including this release) by
 Benjamin Warfield E<lt>bwarfield@cpan.orgE<gt>
+Ruslan Zakirov
+Best Practical Solutions E<lt>modules@bestpractical.comE<gt>
 
 =head2 Copyright
 
